check_columns: Stop with a tidy message when columns are absent from a data...

View source: R/utils.R

check_columnsR Documentation

Stop with a tidy message when columns are absent from a data frame

Description

Stop with a tidy message when columns are absent from a data frame

Usage

check_columns(data, cols, arg_name = "data")

highdir documentation built on July 31, 2026, 5:06 p.m.