hd_venn_intersect: Build an Intersection Entry for hd_geom_venn

View source: R/geom-venn.R

hd_venn_intersectR Documentation

Build an Intersection Entry for hd_geom_venn

Description

Creates one entry describing the overlap region between two or more sets. The ids must match the id values used in the corresponding hd_venn_set() calls.

Usage

hd_venn_intersect(ids, value, name = NULL)

Arguments

ids

Character vector of length >= 2 identifying the overlapping sets. E.g. c("A", "B") for the A-B intersection.

value

Numeric. Area / size of the intersection region.

name

Character or NULL. Optional label for the intersection region. Usually left NULL.

Value

A named list suitable for inclusion in the sets argument of hd_geom_venn().

Examples

hd_venn_intersect(c("A", "B"), value = 2)
#> list(sets = list("A", "B"), value = 2)


highdir documentation built on July 31, 2026, 5:06 p.m.