hd_venn_sets_from_spec: Extract the Set List from an hd_spec_venn Object

View source: R/figure-spec.R

hd_venn_sets_from_specR Documentation

Extract the Set List from an hd_spec_venn Object

Description

Convenience extractor to retrieve the set list stored inside a spec created by hd_spec_venn(). Useful when you want to inspect or extend the set list before passing to hd_make().

Usage

hd_venn_sets_from_spec(spec)

Arguments

spec

An hd_spec_venn object.

Value

The set list (same object that was passed to hd_spec_venn()).

Examples

sets   <- list(hd_venn_set("A", "Oslo", 120))
spec_v <- hd_spec_venn(sets)
hd_venn_sets_from_spec(spec_v)   # returns the original sets list


highdir documentation built on July 31, 2026, 5:06 p.m.