Creates one entry describing the overlap region between two or more sets.
The ids must match the id values used in the corresponding
hd_venn_set() calls.
Value
A named list suitable for inclusion in the sets argument of
hd_geom_venn().
Examples
hd_venn_intersect(c("A", "B"), value = 2)
#> $sets
#> $sets[[1]]
#> [1] "A"
#>
#> $sets[[2]]
#> [1] "B"
#>
#>
#> $value
#> [1] 2
#>
#> list(sets = list("A", "B"), value = 2)