| hd_venn_intersect | R Documentation |
Creates one entry describing the overlap region between two or more sets.
The ids must match the id values used in the corresponding
hd_venn_set() calls.
hd_venn_intersect(ids, value, name = NULL)
ids |
Character vector of length >= 2 identifying the overlapping
sets. E.g. |
value |
Numeric. Area / size of the intersection region. |
name |
Character or |
A named list suitable for inclusion in the sets argument of
hd_geom_venn().
hd_venn_intersect(c("A", "B"), value = 2)
#> list(sets = list("A", "B"), value = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.