Skip to contents

Creates one set entry describing a single, non-overlapping set region. Pass the result directly into the sets list of hd_geom_venn().

Usage

hd_venn_set(id, name, value)

Arguments

id

Character. Short identifier used to reference this set in intersection entries. E.g. "A".

name

Character. Human-readable label shown inside the circle.

value

Numeric. Area / size of this set region (excluding overlaps).

Value

A named list suitable for inclusion in the sets argument of hd_geom_venn().

Examples

hd_venn_set("A", "Animals", 5)
#> $sets
#> $sets[[1]]
#> [1] "A"
#> 
#> 
#> $name
#> [1] "Animals"
#> 
#> $value
#> [1] 5
#> 
#> list(sets = list("A"), name = "Animals", value = 5)