Creates one set entry describing a single, non-overlapping set region.
Pass the result directly into the sets list of hd_geom_venn().
Value
A named list suitable for inclusion in the sets argument of
hd_geom_venn().
Creates one set entry describing a single, non-overlapping set region.
Pass the result directly into the sets list of hd_geom_venn().
A named list suitable for inclusion in the sets argument of
hd_geom_venn().