Skip to contents

Convenience extractor to retrieve the set list stored inside a spec created by hd_spec_venn(). Useful when you want to inspect or extend the set list before passing to hd_make().

Usage

hd_venn_sets_from_spec(spec)

Arguments

spec

An hd_spec_venn object.

Value

The set list (same object that was passed to hd_spec_venn()).

Examples

sets   <- list(hd_venn_set("A", "Oslo", 120))
spec_v <- hd_spec_venn(sets)
hd_venn_sets_from_spec(spec_v)   # returns the original sets list
#> [[1]]
#> [[1]]$sets
#> [[1]]$sets[[1]]
#> [1] "A"
#> 
#> 
#> [[1]]$name
#> [1] "Oslo"
#> 
#> [[1]]$value
#> [1] 120
#> 
#>